[![image](https://img.shields.io/pypi/v/freshchat.svg)](https://pypi.org/project/freshchat/)
[![image](https://img.shields.io/pypi/l/freshchat.svg)](https://pypi.org/project/freshchat/)
[![image](https://img.shields.io/pypi/pyversions/freshchat.svg)](https://pypi.org/project/freshchat/)
[![image](https://readthedocs.org/projects/freshchat/badge/?version=latest&style=flat)](https://freshchat.readthedocs.io/)
[![image](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/ambv/black)
[![](https://github.com/twyla-ai/python-freshchat/workflows/Main%20Workflow/badge.svg)](https://github.com/twyla-ai/python-freshchat/actions)
[![Sonarcloud Status](https://sonarcloud.io/api/project_badges/measure?project=twyla-ai_python-freshchat&metric=alert_status)](https://sonarcloud.io/dashboard?id=twyla-ai_python-freshchat)

# Python Freshchat Client Library
A python client library for [Freshchat (Live Chat Software)](https://www.freshworks.com/live-chat-software/). This library allows users to interact with the Freshchat API to perform actions on the following resources.

* Users
* Channels
* Conversations

This library can also be used to build B2B or C2B live chat clients integrating with the Freshchat API.

## Installation
`pip install freshchat`

## Documentation
The project documentation is available [here](https://freshchat.readthedocs.io/en/latest/). Be sure to check out the [introduction](https://freshchat.readthedocs.io/en/latest/intro.html) for usage examples.

## Reporting Issues and Contributing
This project is maintained on [GitHub](https://github.com/twyla-ai/python-freshchat).
